@@ -77,6 +77,18 @@ class Helpers:
             .decode("utf-8")
         )
 
+    @staticmethod
+    def setup_temp_workspace(src_dir, content_list, path_suffix=""):
+        """THis function creates a temporary workspace folder with some files in it with the respective name and contents provided in content List"""
+        # @param -> path_suffix: recursive path folder if needed
+        # @param -> content_list: expects a list of objects with keys filename and contents to be written in that file
+        path_with_suffix = os.path.join(src_dir, path_suffix)
+        os.makedirs(path_with_suffix, exist_ok=True)
+        for f in content_list:
+            with open(os.path.join(path_with_suffix, f["filename"]), "w") as h:
+                h.write(f["contents"])
+        return path_with_suffix
+
 
 @pytest.fixture
 def helpers():
