@@ -1,5 +1,6 @@
 from unittest.mock import patch
 import argparse
+import os
 
 
 def test_setup_parser():
@@ -14,7 +15,7 @@ def test_setup_parser():
         "--build-definition": "oniro.json",
         "--runtime": "docker",
         "--image": None,
-        "--src-dir": None,
+        "--src-dir": "test",
         "--build-dir-name": "build",
         "--local-manifest": None,
         "--pinned-manifest": None,
@@ -24,12 +25,13 @@ def test_setup_parser():
         data.extend([key, parser_map[key]])
     with patch("sys.argv", data):
         data = setup_parser().parse_args()
+        print(data)
         assert all(
             [
                 data.build_definition == parser_map["--build-definition"],
                 data.runtime == parser_map["--runtime"],
                 data.image == parser_map["--image"],
-                data.src_dir == parser_map["--src-dir"],
+                data.src_dir == os.path.abspath(parser_map["--src-dir"]),
                 data.build_dir_name == parser_map["--build-dir-name"],
                 data.local_manifest == parser_map["--local-manifest"],
                 data.pinned_manifest == parser_map["--pinned-manifest"],
