@@ -191,3 +191,67 @@ def test_prepare(oebuild_repo_init_object):
             if oebuild_obj.bblayers_conf:
                 for val in oebuild_obj.bblayers_conf:
                     assert val in data
+
+
+def test_publish_artifacts(helpers, tmpdir_factory):
+    from tuxbake.models import OEBuild
+
+    temp_src_dir = tmpdir_factory.mktemp("openbmc")
+    build_definition = {
+        "src_dir": temp_src_dir,
+        "distro": "openbmc-openpower",
+        "artifacts": [],
+        "artifacts_dir": "test-output",
+        "build_dir": "build",
+        "machine": "palmetto",
+        "sources": {
+            "git_trees": [
+                {"url": "http://git.yoctoproject.org/git/poky"},
+                {"url": "https://github.com/ndechesne/meta-qcom"},
+            ]
+        },
+    }
+    """ For openbmc builds """
+    # setup bitbake-environment file
+    deploy_dir = "openbmc/deploy"
+    bitbake_env_dir = f"openbmc/{build_definition['build_dir']}"
+    content_list = [
+        {
+            "filename": "bitbake-environment",
+            "contents": f"DEPLOY_DIR={temp_src_dir}/{deploy_dir}",
+        }
+    ]
+    helpers.setup_temp_workspace(temp_src_dir, content_list, bitbake_env_dir)
+    # setup artifacts file to be copied
+    content_list = [{"filename": "one.txt", "contents": "file one"}]
+    helpers.setup_temp_workspace(temp_src_dir, content_list, deploy_dir)
+    oebuild_obj = OEBuild(**build_definition)
+    # calling publish artifacts and artifacts will be published at 'artifacts_dir' inside our src_dir"
+    oebuild_obj.publish_artifacts()
+    with open(f"{temp_src_dir}/{build_definition['artifacts_dir']}/one.txt") as f:
+        data = f.read()
+        assert data == "file one"
+
+    """ For Non-openbmc builds """
+    # setup bitbake-environment file
+    temp_src_dir = tmpdir_factory.mktemp("non-openbmc")
+    deploy_dir = "build/deploy"
+    bitbake_env_dir = build_definition["build_dir"]
+    content_list = [
+        {
+            "filename": "bitbake-environment",
+            "contents": f"DEPLOY_DIR={temp_src_dir}/{deploy_dir}",
+        }
+    ]
+    helpers.setup_temp_workspace(temp_src_dir, content_list, bitbake_env_dir)
+    # setup artifacts file to be copied
+    content_list = [{"filename": "one.txt", "contents": "file one"}]
+    helpers.setup_temp_workspace(temp_src_dir, content_list, deploy_dir)
+    build_definition["distro"] = "test-distro"
+    build_definition["src_dir"] = temp_src_dir
+    oebuild_obj = OEBuild(**build_definition)
+    # calling publish artifacts and artifacts will be published at 'artifacts_dir' inside our src_dir"
+    oebuild_obj.publish_artifacts()
+    with open(f"{temp_src_dir}/{build_definition['artifacts_dir']}/one.txt") as f:
+        data = f.read()
+        assert data == "file one"
