@@ -4,6 +4,7 @@
 import argparse
 from tuxmake.runtime import Runtime
 from typing import List
+import os
 
 
 class supported:
@@ -50,6 +51,7 @@ def setup_parser() -> argparse.ArgumentParser:
         "--src-dir",
         help="source directory where the sources will be downloaded",
         default="source",
+        type=os.path.abspath,
     )
     group.add_argument(
         "--sync-only",
