@@ -14,6 +14,8 @@ def build(**kwargs):
         oebuild.do_build()
     except (KeyboardInterrupt, Terminated) as ex:
         print("tuxbake Interrupted")
+    if oebuild.artifacts_dir:
+        oebuild.publish_artifacts()
     oebuild.do_cleanup()
     signal.signal(signal.SIGTERM, old_sigterm)
     return oebuild
