@@ -42,7 +42,6 @@ def validate_environment(environment):
         dict,
         f"Expected a dict in environment: '{environment}'",
     )
-    # TODO: check key value pair of type string
     for key, value in environment.items():
         check_instance(
             key,
@@ -94,6 +93,14 @@ def validate_git_sha(git_sha):
         )
 
 
+def validate_git_dest(dest):
+    check_instance(
+        dest,
+        str,
+        f"Unexpected argument for dest in git_trees object, expected string: '{dest}'",
+    )
+
+
 def validate_container(container):
 
     supported_containers = [
@@ -150,3 +157,17 @@ def validate_bblayers_conf(bblayers_conf):
             str,
             f"Unexpected argument for bblayers_conf data, expected string: '{bb_conf}'",
         )
+
+
+def validate_artifacts(artifacts):
+    check_instance(
+        artifacts,
+        list,
+        f"Unexpected argument for artifacts, expected list: '{artifacts}'",
+    )
+    for artifact in artifacts:
+        check_instance(
+            artifact,
+            str,
+            f"Unexpected argument for artifacts data, expected string: '{artifact}'",
+        )
