@@ -87,15 +87,18 @@ def find_bitbake_env(env_file, key):
                 return line.split("=")[1].strip().replace('"', "")
 
 
-def copy_artifacts(artifacts, src_dir, artifacts_dir):
-    bitbake_env_file = f"{src_dir}/build/bitbake-environment"
-    if artifacts:
-        bitbake_env = find_bitbake_env(bitbake_env_file, "DEPLOY_DIR")
-        dir_paths = [f"{bitbake_env}/{artifact}" for artifact in artifacts]
-        dirs = " ".join(dir_paths)
-    else:
-        dirs = find_bitbake_env(bitbake_env_file, "DL_DIR")
-    if dirs:
+def copy_artifacts(artifacts, src_dir, artifacts_dir, bitbake_env_file):
+    if not os.path.exists(bitbake_env_file):
+        return
+    deploy_dir = find_bitbake_env(bitbake_env_file, "DEPLOY_DIR")
+    if deploy_dir:
+        if artifacts:
+            dir_paths = [f"{deploy_dir}/{artifact}" for artifact in artifacts]
+            dirs = " ".join(dir_paths)
+        else:
+            # whole DEPLOY_DIR to be published
+            dirs = f"{deploy_dir}/."
+
         if not os.path.exists(artifacts_dir):
             os.makedirs(artifacts_dir)
         else:
@@ -105,6 +108,9 @@ def copy_artifacts(artifacts, src_dir, artifacts_dir):
             run_cmd(cmd, src_dir)
         cmd = f"cp -R {dirs} {artifacts_dir}".split()
         run_cmd(cmd, src_dir, fail_ok=True)
+        # copy bitbake-environment files as well
+        cmd = f"cp -R {bitbake_env_file} {artifacts_dir}".split()
+        run_cmd(cmd, src_dir, fail_ok=True)
 
 
 def run_cmd(cmd, src_dir, env=None, fail_ok=False):
